@@ -1,7 +1,28 @@
-/* -*- mode: C; c-basic-offset: 4 -*- */
+/* -*- mode: C; c-basic-offset: 4 -*-
+ * pyorbit - a Python language mapping for the ORBit2 CORBA ORB
+ * Copyright (C) 2002-2003  James Henstridge <james@daa.com.au>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+*/
+
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
+
+#define PY_SIZE_T_CLEAN
+
 #include "pyorbit-private.h"
 
 static void
@@ -95,15 +116,8 @@ pycorba_object__is_nil(PyCORBA_Object *self)
 static PyObject *
 pycorba_object__duplicate(PyCORBA_Object *self)
 {
-    CORBA_Object ret;
-    CORBA_Environment ev;
-
-    CORBA_exception_init(&ev);
-    ret = CORBA_Object_duplicate(self->objref, &ev);
-
-    if (pyorbit_check_ex(&ev))
-	return NULL;
-    return pycorba_object_new(ret);
+    /* pycorba_object_new() duplicates the objref ... */
+    return pycorba_object_new(self->objref);
 }
 
 static PyObject *
@@ -313,7 +327,6 @@ pycorba_object_new(CORBA_Object objref)
 	Py_INCREF(Py_None);
 	return Py_None;
     }
-
     stub = (PyTypeObject *)pyorbit_get_stub_from_objref(objref);
     if (!stub) stub = &PyCORBA_Object_Type; /* fall back */
 
@@ -324,5 +337,7 @@ pycorba_object_new(CORBA_Object objref)
 	return NULL;
 
     self->objref = objref;
+    CORBA_Object_duplicate(self->objref, NULL);
     return (PyObject *)self;
 }
+
